==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>المعلومات الأساسية</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>إضافة  إلى الألبوم</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>كل الصور</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>قتح الصورة.</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>حذف من اﻷلبوم</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>إزلة من المفضلة</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>إضافة إلى المفضلة</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>ليس لديك الصلاحية لرؤية الصورة</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>تاريخ التعديل</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>حجم الملف</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>تم حفظ التاريخ</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>وضع التعرض</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>برنامج التعرض</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>زمن التعرض </translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>فلاش </translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>فتحة العدسة</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>البعد البؤري </translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO </translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>أقصى فتحة </translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>وضع القياس </translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>توازن اللون الأبيض </translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>تعويض الفلاش</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>طراز العدسة</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>مساحة اﻷلوان</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>طراز الكاميرا</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>الأبعاد</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>العلامة الدلالية</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>رجوع</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>حجم 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>ملء النافذة</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير عكس اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير باتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>الخروج من وضع ملء الشاشة</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة التسمية</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>إظهار نافذة التنقل </translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>إخفاء نافذة التنقل </translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تعيين كخلفية</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>موافق</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>ادخال اسم جديد</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ايقاف مؤقت</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>لم يتم العثور على صورة</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>لم يتم العثور على أي صورة</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.21.orig.tar.xz: image-editor-1.0.21/libimageviewer/translations/libimageviewer_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>المعلومات الأساسية</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>إضافة  إلى الألبوم</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>ألبوم جديد</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>كل الصور</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>قتح الصورة.</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>حذف من اﻷلبوم</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>إزلة من المفضلة</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>إضافة إلى المفضلة</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>ليس لديك الصلاحية لرؤية الصورة</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>تاريخ التعديل</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>حجم الملف</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>تم حفظ التاريخ</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>وضع التعرض</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>برنامج التعرض</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>زمن التعرض </translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>فلاش </translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>فتحة العدسة</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>البعد البؤري </translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO </translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>أقصى فتحة </translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>وضع القياس </translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>توازن اللون الأبيض </translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>تعويض الفلاش</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>طراز العدسة</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>مساحة اﻷلوان</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>طراز الكاميرا</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>الأبعاد</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>العلامة الدلالية</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>رجوع</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>حجم 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>ملء النافذة</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>تدوير عكس اتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>تدوير باتجاه عقارب الساعة</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>الخروج من وضع ملء الشاشة</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>ملء الشاشة</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>طباعة</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>عرض الشرائح</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>إعادة التسمية</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>إظهار نافذة التنقل </translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>إخفاء نافذة التنقل </translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>تعيين كخلفية</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>عرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>معلومات الصورة</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>موافق</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>ادخال اسم جديد</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>السابق</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ايقاف مؤقت</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>التالي</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>لم يتم العثور على صورة</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>لم يتم العثور على أي صورة</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
